@@ -4,10 +4,10 @@ yadirSetKeyWordsBids <- function(KeywordIds       = NULL,
                                  StrategyPriority = c(NA, "LOW", "NORMAL", "HIGH" ),
                                  SearchBid        = NULL,
                                  NetworkBid       = NULL,
-                                 Login            = NULL,
+                                 Login            = getOption("ryandexdirect.user"),
                                  Token            = NULL,
-                                 AgencyAccount    = NULL,
-                                 TokenPath        = getwd()) {
+                                 AgencyAccount    = getOption("ryandexdirect.agency_account"),
+                                 TokenPath        = yadirTokenPath()) {
   # start time
   start_time  <- Sys.time()
   
